<?xml version="1.0" encoding="UTF-8"?>
<!-- rcCode_vs_Peildatum_v1.0.xslt, 5 april 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:gen="http://ei.vektis.nl/generiekefuncties">
		
	<!-- deze routine voert de volgende controle uit: 
		 	- als Code een waarde bevat
				- controleer of Code voorkomt in de codelijst met bestandsnaam Codelijst; als Code niet voorkomt, dan wordt retourcode RetourcodeBestaanbaarheid geretourneerd; geen verdere controles

			- als Code voorkomt en Peildatum is gevuld
				- tenzij RetourcodeIngangsdatum waarde 'nvt' heeft, controleer of de ingangsdatum van Code kleiner of gelijk is aan Peildatum; als dit niet het geval is, dan wordt retourcode RetourcodeIngangsdatum geretourneerd
				- tenzij RetourcodeExpiratiedatum waarde 'nvt' heeft, controleer of Peildatum voor de expiratiedatum ligt; als dit niet het geval is, dan wordt retourcode RetourcodeExpiratiedatum geretourneerd -->
	
	<xsl:template name="rcCode_vs_Peildatum">
		<xsl:param name="Codelijst"/>
		<xsl:param name="RetourcodeBestaanbaarheid"/>
		<xsl:param name="RetourcodeIngangsdatum"/>
		<xsl:param name="RetourcodeExpiratiedatum"/>
		<xsl:param name="Code"/>
		<xsl:param name="Peildatum"/>
		
		<!-- als Code een waarde bevat, controleer Code -->
		<xsl:if test="$Code != ''">
			<!-- controleer of Code bestaat -->
			<xsl:choose>
				<xsl:when test="not(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code])">
					<gen:Feedback>
						<gen:Retourcode><xsl:value-of select="$RetourcodeBestaanbaarheid"/></gen:Retourcode>
							<!-- som de elementen op die de fout veroorzaken -->
							<gen:BetrokkenElement>
								<gen:Elementnaam><xsl:value-of select="local-name($Code)"/></gen:Elementnaam>
								<gen:Elementwaarde><xsl:value-of select="$Code"/></gen:Elementwaarde>
							</gen:BetrokkenElement>
					</gen:Feedback>
				</xsl:when>
				<xsl:otherwise>
					<!-- als code bestaat en Peildatum is gevuld en RetourcodeIngangsdatum niet waarde 'nvt' heeft, verifieer of Code al bestond op Peildatum (er moet gelden: Ingangsdatum <= Peildatum) -->
					<xsl:if test="$Peildatum != '' and $RetourcodeIngangsdatum != 'nvt' and document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum != '' and
								translate($Peildatum,'-','') &lt; translate(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum,'-','')">
						<gen:Feedback>
							<gen:Retourcode><xsl:value-of select="$RetourcodeIngangsdatum"/></gen:Retourcode>
								<!-- som de elementen op die de fout veroorzaken -->
								<gen:BetrokkenElement>
									<gen:Elementnaam><xsl:value-of select="local-name($Code)"/></gen:Elementnaam>
									<gen:Elementwaarde><xsl:value-of select="$Code"/></gen:Elementwaarde>
								</gen:BetrokkenElement>
								<gen:BetrokkenElement>
									<gen:Elementnaam><xsl:value-of select="local-name($Peildatum)"/></gen:Elementnaam>
									<gen:Elementwaarde><xsl:value-of select="$Peildatum"/></gen:Elementwaarde>
								</gen:BetrokkenElement>
								<gen:BetrokkenElement>
									<gen:Elementnaam><xsl:value-of select="name(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum)"/></gen:Elementnaam>
									<gen:Elementwaarde><xsl:value-of select="document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum"/></gen:Elementwaarde>
								</gen:BetrokkenElement>
						</gen:Feedback>
					</xsl:if>
					<!-- als code bestaat en Peildatum is gevuld en RetourcodeExpiratiedatum niet waarde 'nvt' heeft, verifieer of Code niet is geëxpireerd op Peildatum (er moet gelden: Peildatum < Expiratiedatum) -->
					<xsl:if test="$Peildatum != '' and $RetourcodeExpiratiedatum != 'nvt' and document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum != '' and 
								not(translate($Peildatum,'-','') &lt; translate(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum,'-',''))">
						<gen:Feedback>
							<gen:Retourcode><xsl:value-of select="$RetourcodeExpiratiedatum"/></gen:Retourcode>
								<!-- som de elementen op die de fout veroorzaken -->
								<gen:BetrokkenElement>
									<gen:Elementnaam><xsl:value-of select="local-name($Code)"/></gen:Elementnaam>
									<gen:Elementwaarde><xsl:value-of select="$Code"/></gen:Elementwaarde>
								</gen:BetrokkenElement>
								<gen:BetrokkenElement>
									<gen:Elementnaam><xsl:value-of select="local-name($Peildatum)"/></gen:Elementnaam>
									<gen:Elementwaarde><xsl:value-of select="$Peildatum"/></gen:Elementwaarde>
								</gen:BetrokkenElement>
								<gen:BetrokkenElement>
									<gen:Elementnaam><xsl:value-of select="name(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum)"/></gen:Elementnaam>
									<gen:Elementwaarde><xsl:value-of select="document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum"/></gen:Elementwaarde>
								</gen:BetrokkenElement>
						</gen:Feedback>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
