<?xml version="1.0" encoding="UTF-8"?>
<!-- vz845_586v1.0_Vecozo_stap1_v1, 10 april 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:gen="http://ei.vektis.nl/generiekefuncties"
xmlns:vz845="http://ei.vektis.nl/vz/vz845/v1_0"
xmlns:vz846="http://ei.vektis.nl/vz/vz846/v1_0">

	<!-- VALXSLT 2 TRAPS RETOURBERICHT  - versie Vecozo -->
	<!-- Deze xslt doet stap 1, i.e. tussenresultaat retourbericht met alle klassen, identificerende gegevens van klassen en geconstateerde fouten -->
	
	<!-- Laden Configuratiefile met waarde voor Omgeving en Huidige datum	-->
	<xsl:import href="config_Vecozo.xml"/>
	
	<xsl:import href="rcCode_vs_Peildatum_v1.0.xslt"/>
	<xsl:import href="rcDatum_vs_Peildatum_v1.0.xslt"/>
	<xsl:import href="rcDatum_vs_Huidigedatum_v1.0.xslt"/>
	<xsl:import href="rcCheckWaarde_v1.0.xslt"/>
	<xsl:import href="rcCheckWaarde_ConditioneelElement_v1.0.xslt"/>
	<xsl:import href="rcCheckWaarde_ConditioneleWaarde_v1.0.xslt"/>
	<xsl:import href="rcCheckVoorkomen_v1.0.xslt"/>
	<xsl:import href="rcCheckVoorkomen_ConditioneleWaarde_v1.0.xslt"/>
	<xsl:import href="rcTotaalbedrag_vs_Details_v1.0.xslt"/>
	<xsl:import href="rcTotaalbedragDC_vs_Details_v1.0.xslt"/>
	<xsl:import href="rc9717.xslt"/>
	
	<!-- Uitvoer is vz846_587 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="TargetNameSpace" select="'vz846:'"/>

	<xsl:variable name="Berichtsoort" select="//vz845:Bericht/vz845:Header/vz845:Berichtsoort"/> 
	<xsl:variable name="Berichtcode" select="//vz845:Bericht/vz845:Header/vz845:Berichtcode"/> 
	<xsl:variable name="Verzender" select="//vz845:Bericht/vz845:Header/vz845:Verzender"/>
	<xsl:variable name="VerzenderRol" select="//vz845:Bericht/vz845:Header/vz845:VerzenderRol"/>
	<xsl:variable name="Ontvanger" select="//vz845:Bericht/vz845:Header/vz845:Ontvanger"/> 
	<xsl:variable name="OntvangerRol" select="//vz845:Bericht/vz845:Header/vz845:OntvangerRol"/> 
	<xsl:variable name="Verzenddatum" select="//vz845:Bericht/vz845:Header/vz845:Verzenddatum"/>
	<xsl:variable name="BegindatumVerwerkingsperiode" select="//vz845:Bericht/vz845:DeclaratieContext/vz845:BegindatumVerwerkingsperiode"/>
	<xsl:variable name="EinddatumVerwerkingsperiode" select="//vz845:Bericht/vz845:DeclaratieContext/vz845:EinddatumVerwerkingsperiode"/>
	<xsl:variable name="Factuurdatum" select="//vz845:Bericht/vz845:DeclaratieContext/vz845:Factuurdatum"/>
		
	<!-- Controleer op fouten in de klasse Header -->
	<!-- RC002: VerzenderRol moet voorkomen in ketenpartij codelijst. | Indien VerzenderRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van VerzenderRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van VerzenderRol. -->
	<xsl:variable name="rc002">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9302'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9303'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9304'"/>
			<xsl:with-param name="Code" select="$VerzenderRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- RC004: OntvangerRol moet voorkomen in ketenpartij codelijst. | Indien OntvangerRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van OntvangerRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van OntvangerRol. -->
	<xsl:variable name="rc004">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9311'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9312'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9313'"/>
			<xsl:with-param name="Code" select="$OntvangerRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC001: De waarde van Berichtsoort moet voldoen aan de omgeving van VECOZO (productie of test) -->
	<xsl:variable name="vc001">
		<xsl:call-template name="rcCheckWaarde">
			<xsl:with-param name="TeControlerenElement" select="$Berichtsoort"/>
			<xsl:with-param name="VereisteWaarde" select="$OmgevingVecozo"/>
			<xsl:with-param name="Retourcode" select="'8028'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC002: Indien Berichtcode = 586 (= Specificatie declaratie WUVV), dan mag alleen Verzender = 9990 (=CAK) voorkomen. -->
		<xsl:variable name="vc002">
		<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
			<xsl:with-param name="TeControlerenElement" select="$Verzender"/>
			<xsl:with-param name="VereisteWaarde" select="'9990'"/>
			<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
			<xsl:with-param name="ConditioneleWaarde" select="'586'"/>
			<xsl:with-param name="Retourcode" select="'9715'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC003:Indien Berichtcode = 586 (= Specificatie declaratie WUVV), dan mag alleen VerzenderRol = 7 (= CAK) voorkomen. -->
		<xsl:variable name="vc003">
		<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
			<xsl:with-param name="TeControlerenElement" select="$VerzenderRol"/>
			<xsl:with-param name="VereisteWaarde" select="'7'"/>
			<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
			<xsl:with-param name="ConditioneleWaarde" select="'586'"/>
			<xsl:with-param name="Retourcode" select="'9262'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC004:Indien Berichtcode = 586 (= Declaratie WUVV), dan mag alleen OntvangerRol 3 (= Zorgverzekeraar) voorkomen. -->
		<xsl:variable name="vc004">
		<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
			<xsl:with-param name="TeControlerenElement" select="$OntvangerRol"/>
			<xsl:with-param name="VereisteWaarde" select="'3'"/>
			<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
			<xsl:with-param name="ConditioneleWaarde" select="'586'"/>
			<xsl:with-param name="Retourcode" select="'9263'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC005:De waarde van Verzenddatum moet kleiner zijn dan of gelijk zijn aan de waarde van de huidige datum. -->
	<xsl:variable name="vc005">
		<xsl:call-template name="rcDatum_vs_Huidigedatum">
			<xsl:with-param name="TeControlerenDatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'8986'" />
		</xsl:call-template>
	</xsl:variable>
	<!-- Zet variabele voor fouten in de klasse Header -->
	<xsl:variable name="FoutInHeader">
		<xsl:if test="$rc002='' and $rc004='' and $vc001='' and $vc002='' and $vc003='' and $vc004='' and $vc005=''">false</xsl:if>
	</xsl:variable>

	<!-- Controleer op fouten in de klasse DeclaratieContext -->
	<!-- VC006:De waarde van ZorgverzekeraarscodeDeclaratie moet gelijk zijn aan de waarde van Ontvanger. -->
	<xsl:variable name="vc006">
		<xsl:call-template name="rcCheckWaarde">
			<xsl:with-param name="TeControlerenElement" select="//vz845:Bericht/vz845:DeclaratieContext/vz845:ZorgverzekeraarscodeDeclaratie"/>
			<xsl:with-param name="VereisteWaarde" select="$Ontvanger"/>
			<xsl:with-param name="Retourcode" select="'9716'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC007:De waarde van BegindatumVerwerkingsperiode moet kleiner of gelijk zijn aan de waarde van EinddatumVerwerkingsperiode. -->
	<xsl:variable name="vc007">
		<xsl:call-template name="rcDatum_vs_Peildatum">
			<xsl:with-param name="TeControlerenDatum" select="$BegindatumVerwerkingsperiode"/>
			<xsl:with-param name="Peildatum" select="$EinddatumVerwerkingsperiode"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'8372'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC008:De waarde van Factuurdatum moet kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->
	<xsl:variable name="vc008">
		<xsl:call-template name="rcDatum_vs_Peildatum">
			<xsl:with-param name="TeControlerenDatum" select="$Factuurdatum"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'9265'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- Zet variabele voor fouten in de klasse DeclaratieContext -->
	<xsl:variable name="FoutInDeclaratieContext">
		<xsl:if test="$vc006='' and $vc007='' and $vc008=''">false</xsl:if>
	</xsl:variable>
	
	<!-- Controleer op fouten in Overzicht -->
	<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst. -->
	<xsl:variable name="rc012">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
			<xsl:with-param name="Code" select="//vz845:Bericht/vz845:Overzicht/vz845:TotaalBedragDeclaratieregels/vz845:Valuta"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- RC014: DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst. -->
	<xsl:variable name="rc014">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
			<xsl:with-param name="Code" select="//vz845:Bericht/vz845:Overzicht/vz845:TotaalBedragDeclaratieregels/vz845:DebetCreditCode"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC009:TotaalAantalDecaratieregels moet gelijk zijn aan het aantal Declaratieregels. -->
	<xsl:variable name="vc009">
		<xsl:call-template name="rc9717">
			<xsl:with-param name="TotaalAantalDeclaratieregels" select="//vz845:Bericht/vz845:Overzicht/vz845:TotaalAantalDeclaratieregels"/>
			<xsl:with-param name="AantalDeclaratieregels" select="count(//vz845:Bericht/vz845:Declaratieregel)"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC010:TotaalBedragDeclaratieregels moet gelijk zijn aan de som van het Bedrag van alle DebetDeclaratieregels en het Bedrag van alle CreditDeclaratieregels rekening houdend met debet/credit. -->
	<xsl:variable name="vc010">
		<xsl:call-template name="rcTotaalbedragDC_vs_Details">
			<xsl:with-param name="NaamBedrag" select="'TotaalBedragDeclaratieregels'"/>
			<xsl:with-param name="TotaalBedrag" select="//vz845:Bericht/vz845:Overzicht/vz845:TotaalBedragDeclaratieregels/vz845:Bedrag"/>
			<xsl:with-param name="TotaalBedragDCIndicator" select="//vz845:Bericht/vz845:Overzicht/vz845:TotaalBedragDeclaratieregels/vz845:DebetCreditCode"/>
			<xsl:with-param name="TotaalDebetBedragen" select="sum(//vz845:Bericht/vz845:Declaratieregel/vz845:DebetDeclaratieregel/vz845:Bedrag/vz845:Bedrag)"/>
			<xsl:with-param name="TotaalCreditBedragen" select="sum(//vz845:Bericht/vz845:Declaratieregel/vz845:CreditDeclaratieregel/vz845:Bedrag/vz845:Bedrag)"/>
			<xsl:with-param name="Retourcode" select="'9718'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC011:TotaalBedragDeclaratieregels/Valuta = EUR. -->
	<xsl:variable name="vc011">
		<xsl:call-template name="rcCheckWaarde">
			<xsl:with-param name="TeControlerenElement" select="//vz845:Bericht/vz845:Overzicht/vz845:TotaalBedragDeclaratieregels/vz845:Valuta"/>
			<xsl:with-param name="VereisteWaarde" select="'EUR'"/>
			<xsl:with-param name="Retourcode" select="'0031'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- Zet variabele voor fouten in de klasse Overzicht -->
	<xsl:variable name="FoutInOverzicht">
		<xsl:if test="$rc012='' and $rc014='' and $vc009='' and $vc010='' and $vc011=''">false</xsl:if>
	</xsl:variable>
	
	<xsl:template match="vz845:Bericht">
		<vz846:Bericht>
			<xsl:choose>
				<!-- Geen errors in de klassen Header, DeclaratieContext en Overzicht, dan hele bericht retour -->
				<xsl:when test="$FoutInHeader='false' and $FoutInDeclaratieContext='false' and $FoutInOverzicht='false'">
					<xsl:apply-templates select="vz845:Header"/>
					<xsl:apply-templates select="vz845:DeclaratieContext"/>
					<xsl:apply-templates select="vz845:Overzicht"/>
					<xsl:apply-templates select="vz845:Declaratieregel"/>
				</xsl:when>
				<!-- Wel errors in de klassen Header, DeclaratieContext en Overzicht, dan alleen Header, DeclaratieContext en Overzicht retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="vz845:Header"/>
					<xsl:apply-templates select="vz845:DeclaratieContext"/>
					<xsl:apply-templates select="vz845:Overzicht"/>
				</xsl:otherwise>
			</xsl:choose>				
		</vz846:Bericht>
	</xsl:template>

	<xsl:template match="vz845:Header">
		<vz846:Header>
			<vz846:Berichtcode>587</vz846:Berichtcode>
			<xsl:apply-templates select="vz845:Berichtversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Berichtsubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Berichtsoort" mode="copy-if-exists"/>
			<!-- als Vecozo is verzender van het retourbericht dan vullen met gegevens van Vecozo, anders met de gegevens van de verzender van het heenbericht -->
			<xsl:choose>
				<xsl:when test="$VerzenderRetourbericht = 'Vecozo'">
					<vz846:VerzenderRol>
						<xsl:value-of select="$VerzenderRolVecozo"/>
					</vz846:VerzenderRol>
				</xsl:when>
				<xsl:otherwise>
					<vz846:Verzender><xsl:value-of select="vz845:Ontvanger"/></vz846:Verzender>
					<vz846:VerzenderRol><xsl:value-of select="vz845:OntvangerRol"/></vz846:VerzenderRol>
				</xsl:otherwise>
			</xsl:choose>
			<!-- Ontvanger in retourbericht is Verzender uit het heenbericht -->
			<vz846:Ontvanger><xsl:value-of select="vz845:Verzender"/></vz846:Ontvanger>
			<!-- OntvangerRol in retourbericht is VerzenderRol uit het heenbericht -->
			<vz846:OntvangerRol><xsl:value-of select="vz845:VerzenderRol"/></vz846:OntvangerRol>
			<vz846:Verzenddatum><xsl:value-of select="$HuidigeDatum"/></vz846:Verzenddatum>
			<!-- als Referentienummer van retourbericht het Referentienummer van het heenbericht hanteren -->
			<xsl:apply-templates select="vz845:Referentienummer" mode="copy-if-exists"/>
			<!-- feedback klasse Header toevoegen -->
			<xsl:copy-of select="$rc002"/>
			<xsl:copy-of select="$rc004"/>
			<xsl:copy-of select="$vc001"/>
			<xsl:copy-of select="$vc002"/>
			<xsl:copy-of select="$vc003"/>
			<xsl:copy-of select="$vc004"/>
			<xsl:copy-of select="$vc005"/>
		</vz846:Header>
	</xsl:template>
		
	<xsl:template match="vz845:DeclaratieContext">
		<vz846:DeclaratieContext>
			<xsl:apply-templates select="vz845:ZorgverzekeraarscodeDeclaratie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:BegindatumVerwerkingsperiode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:EinddatumVerwerkingsperiode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Factuurnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Factuurdatum" mode="copy-if-exists"/>
			<!-- feedback klasse DeclaratieContext toevoegen -->
			<xsl:copy-of select="$vc006"/>
			<xsl:copy-of select="$vc007"/>
			<xsl:copy-of select="$vc008"/>
		</vz846:DeclaratieContext>
	</xsl:template>				

	<xsl:template match="vz845:Overzicht">
		<vz846:Overzicht>
			<xsl:apply-templates select="vz845:TotaalAantalDeclaratieregels" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:TotaalBedragDeclaratieregels"/>
			<!-- feedback klasse Overzicht toevoegen -->
			<xsl:copy-of select="$vc009"/>
			<xsl:copy-of select="$vc010"/>
			<xsl:copy-of select="$vc011"/>
		</vz846:Overzicht>
	</xsl:template>				

	<xsl:template match="vz845:TotaalBedragDeclaratieregels">
		<vz846:TotaalBedragDeclaratieregels>
			<xsl:apply-templates select="vz845:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Valuta" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:DebetCreditCode" mode="copy-if-exists"/>
			<!-- feedback klasse TotaalBedragDeclaratieregels toevoegen -->
			<xsl:copy-of select="$rc012"/>
			<xsl:copy-of select="$rc014"/>
		</vz846:TotaalBedragDeclaratieregels>
	</xsl:template>			
		
	<xsl:template match="vz845:Declaratieregel">
		<vz846:Declaratieregel>
			<xsl:apply-templates select="vz845:DebetDeclaratieregel"/>
			<xsl:apply-templates select="vz845:CreditDeclaratieregel"/>
			<!-- feedback klasse Declaratieregel toevoegen -->
		</vz846:Declaratieregel>
	</xsl:template>				

	<xsl:template match="vz845:DebetDeclaratieregel">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC006: DeclaratieRedenVerzending moet voorkomen in DeclaratieRedenVerzending codelijst. -->
		<xsl:variable name="rc006">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0023-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9734'"/>
				<xsl:with-param name="Code" select="vz845:DeclaratieRedenVerzending"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC012: Bedrag/Valuta = EUR. -->
		<xsl:variable name="vc012">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Bedrag/vz845:Valuta"/>
				<xsl:with-param name="VereisteWaarde" select="'EUR'"/>
				<xsl:with-param name="Retourcode" select="'0031'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC013: Indien Kosten voorkomt moet het BedragVreemdeValuta gelijk zijn aan de som van de kosten van de uitkeringen. -->
		<xsl:variable name="vc013">
			<xsl:if test="vz845:Uitkeringen/vz845:Kosten">
				<xsl:call-template name="rcTotaalbedrag_vs_Details">
					<xsl:with-param name="NaamBedrag" select="'BedragVreemdeValuta'"/>
					<xsl:with-param name="TotaalBedrag" select="vz845:BedragVreemdeValuta/vz845:Bedrag"/>
					<xsl:with-param name="TotaalDebetBedragen" select="(sum(vz845:Uitkeringen/vz845:Kosten/vz845:MedischeZorgkosten/vz845:Bedrag) + 
						sum(vz845:Uitkeringen/vz845:Kosten/vz845:Medicijnkosten/vz845:Bedrag) +
						sum(vz845:Uitkeringen/vz845:Kosten/vz845:Tandartskosten/vz845:Bedrag) +
						sum(vz845:Uitkeringen/vz845:Kosten/vz845:LangdurigeZorgkosten/vz845:Bedrag) +
						sum(vz845:Uitkeringen/vz845:Kosten/vz845:Ziekenhuisopnamekosten/vz845:Bedrag/vz845:Bedrag) +
						sum(vz845:Uitkeringen/vz845:Kosten/vz845:OverigeKosten/vz845:Bedrag/vz845:Bedrag))"/>
					<xsl:with-param name="TotaalCreditBedragen" select="0.00"/>
					<xsl:with-param name="Retourcode" select="'9719'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<!-- VC014: De waarde van DatumRedenVerzending moet kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->
		<xsl:variable name="vc014">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:DatumRedenVerzending"/>
				<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9720'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC015: Indien DeclaratieRedenVerzending = ‘01’ (=COV-check) of ‘02’ (=Akkoord ZV-portaal) dan moet VerzekeringsrechtPeildatum voorkomen. -->
		<xsl:variable name="vc015">
			<xsl:call-template name="rcCheckVoorkomen_ConditioneleWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:VerzekeringsrechtPeildatum"/>
				<xsl:with-param name="Controle" select="'J'"/>
				<xsl:with-param name="ConditioneelElement" select="vz845:DeclaratieRedenVerzending"/>
				<xsl:with-param name="ConditioneleWaarde" select="'01|02'"/>
				<xsl:with-param name="Vergelijking" select="'gelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9721'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:DebetDeclaratieregel>
			<xsl:apply-templates select="vz845:Referentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Persoonsgegevens"/>
			<xsl:apply-templates select="vz845:Bedrag"/>
			<xsl:apply-templates select="vz845:BedragVreemdeValuta"/>
			<xsl:apply-templates select="vz845:CrediteurOrgaan"/>
			<xsl:apply-templates select="vz845:DocumentDatRechtAantoont"/>
			<xsl:apply-templates select="vz845:Uitkeringen"/>
			<!-- feedback klasse DebetDeclaratieregel toevoegen -->
			<xsl:copy-of select="$rc006"/>
			<xsl:copy-of select="$vc012"/>
			<xsl:copy-of select="$vc013"/>
			<xsl:copy-of select="$vc014"/>
			<xsl:copy-of select="$vc015"/>
		</vz846:DebetDeclaratieregel>
	</xsl:template>				

	<xsl:template match="vz845:CreditDeclaratieregel">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- VC016: Bedrag/Valuta = EUR. -->
		<xsl:variable name="vc016">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Bedrag/vz845:Valuta"/>
				<xsl:with-param name="VereisteWaarde" select="'EUR'"/>
				<xsl:with-param name="Retourcode" select="'0031'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC017: Indien de valuta van BedragVreemdeValuta <> Euro, dan moet bedrag koersverschil voorkomen.  -->
		<xsl:variable name="vc017">
			<xsl:call-template name="rcCheckVoorkomen_ConditioneleWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:BedragKoersVerschil"/>
				<xsl:with-param name="Controle" select="'J'"/>
				<xsl:with-param name="ConditioneelElement" select="vz845:BedragVreemdeValuta/vz845:Valuta"/>
				<xsl:with-param name="ConditioneleWaarde" select="'EUR'"/>
				<xsl:with-param name="Vergelijking" select="'ongelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9722'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC018: Bedrag/Valuta = EUR. -->
		<xsl:variable name="vc018">
				<xsl:call-template name="rcCheckWaarde_ConditioneelElement">
					<xsl:with-param name="TeControlerenElement" select="vz845:BedragKoersVerschil/vz845:Valuta"/>
					<xsl:with-param name="VereisteWaarde" select="'EUR'"/>
					<xsl:with-param name="ConditioneelElement" select="vz845:BedragKoersVerschil"/>
					<xsl:with-param name="Retourcode" select="'0031'"/>
				</xsl:call-template>
		</xsl:variable>
		<vz846:CreditDeclaratieregel>
			<xsl:apply-templates select="vz845:Referentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Persoonsgegevens"/>
			<xsl:apply-templates select="vz845:Bedrag"/>
			<xsl:apply-templates select="vz845:BedragVreemdeValuta"/>
			<xsl:apply-templates select="vz845:BedragKoersVerschil"/>
			<!-- feedback klasse CreditDeclaratieregel toevoegen -->
			<xsl:copy-of select="$vc016"/>
			<xsl:copy-of select="$vc017"/>
			<xsl:copy-of select="$vc018"/>
		</vz846:CreditDeclaratieregel>
	</xsl:template>				

	<xsl:template match="vz845:Bedrag">
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:Bedrag>
			<!-- feedback klasse Bedrag toevoegen -->
			<xsl:copy-of select="$rc012"/>
		</vz846:Bedrag>
	</xsl:template>			
		
	<xsl:template match="vz845:BedragVreemdeValuta">
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:BedragVreemdeValuta>
			<!-- feedback klasse BedragVreemdeValuta toevoegen -->
			<xsl:copy-of select="$rc012"/>
		</vz846:BedragVreemdeValuta>
	</xsl:template>			
		
	<xsl:template match="vz845:BedragKoersVerschil">
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
	<!-- RC014: DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst. -->
	<xsl:variable name="rc014">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
			<xsl:with-param name="Code" select="vz845:DebetCreditCode"/>
		</xsl:call-template>
	</xsl:variable>
		<vz846:BedragKoersVerschil>
			<!-- feedback klasse BedragKoersVerschil toevoegen -->
			<xsl:copy-of select="$rc012"/>
			<xsl:copy-of select="$rc014"/>
		</vz846:BedragKoersVerschil>
	</xsl:template>			
		
	<xsl:template match="vz845:Persoonsgegevens">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC008: GeslachtCode moet voorkomen in code geslacht codelijst. -->
		<xsl:variable name="rc008">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD046-NEN.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9735'"/>
				<xsl:with-param name="Code" select="vz845:GeslachtCode"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC020: Indien DebetDeclaratieregel/ DeclaratieRedenVerzending = 01 (COV-controle) of 02 (Akkoord ZV-portaal), dan moet PINVastgesteld voorkomen.  -->
		<xsl:variable name="vc020">
			<xsl:call-template name="rcCheckVoorkomen_ConditioneleWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:PINVastgesteld"/>
				<xsl:with-param name="Controle" select="'J'"/>
				<xsl:with-param name="ConditioneelElement" select="../vz845:DeclaratieRedenVerzending"/>
				<xsl:with-param name="ConditioneleWaarde" select="'01|02'"/>
				<xsl:with-param name="Vergelijking" select="'gelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9723'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC021: De waarde van Geboortedatum moet kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->
		<xsl:variable name="vc021">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Geboortedatum"/>
				<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9741'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:Persoonsgegevens>
			<xsl:apply-templates select="vz845:PINVerzekeringsland"/>
			<xsl:apply-templates select="vz845:PINWoonlandOfVerblijfsland"/>
			<xsl:apply-templates select="vz845:PINVastgesteld"/>
			<!-- feedback klasse Persoonsgegevens toevoegen -->
			<xsl:copy-of select="$rc008"/>
			<xsl:copy-of select="$vc020"/>
			<xsl:copy-of select="$vc021"/>
		</vz846:Persoonsgegevens>
	</xsl:template>				

	<xsl:template match="vz845:PINVerzekeringsland">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC013: SoortPIN moet voorkomen in Soort PIN codelijst. -->
		<xsl:variable name="rc013">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0022-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9740'"/>
				<xsl:with-param name="Code" select="vz845:SoortPIN"/>
			</xsl:call-template>
		</xsl:variable>

		<vz846:PINVerzekeringsland>
			<!-- feedback klasse PINVerzekeringsland toevoegen -->
			<xsl:copy-of select="$rc013"/>
		</vz846:PINVerzekeringsland>
	</xsl:template>				

	<xsl:template match="vz845:PINWoonlandOfVerblijfsland">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC013: SoortPIN moet voorkomen in Soort PIN codelijst. -->
		<xsl:variable name="rc013">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0022-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9740'"/>
				<xsl:with-param name="Code" select="vz845:SoortPIN"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:PINWoonlandOfVerblijfsland>
			<!-- feedback klasse PINWoonlandOfVerblijfsland toevoegen -->
			<xsl:copy-of select="$rc013"/>
		</vz846:PINWoonlandOfVerblijfsland>
	</xsl:template>				

	<xsl:template match="vz845:PINVastgesteld">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC013: SoortPIN moet voorkomen in Soort PIN codelijst. -->
		<xsl:variable name="rc013">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0022-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9740'"/>
				<xsl:with-param name="Code" select="vz845:SoortPIN"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC032: Indien PINVastgesteld voorkomt dan moet SoortPIN voorkomen. -->
		<xsl:variable name="vc032">
			<xsl:call-template name="rcCheckVoorkomen">
				<xsl:with-param name="TeControlerenElement" select="vz845:SoortPIN"/>
				<xsl:with-param name="Controle" select="'J'"/>
				<xsl:with-param name="Retourcode" select="'9728'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:PINVastgesteld>
			<!-- feedback klasse PINVastgesteld toevoegen -->
			<xsl:copy-of select="$rc013"/>
			<xsl:copy-of select="$vc032"/>
		</vz846:PINVastgesteld>
	</xsl:template>				

	<xsl:template match="vz845:CrediteurOrgaan">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC007: Landcode moet voorkomen in LandCode codelijst. -->
		<xsl:variable name="rc007">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0027-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9742'"/>
				<xsl:with-param name="Code" select="vz845:Landcode"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC019: Landcode moet overeenkomen met landcode in Orgaancode (positie 1 en 2) -->
		<xsl:variable name="vc019">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Landcode"/>
				<xsl:with-param name="VereisteWaarde" select="substring(vz845:Orgaancode,1,2)"/>
				<xsl:with-param name="Retourcode" select="'9021'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:CrediteurOrgaan>
			<!-- feedback klasse CrediteurOrgaan toevoegen -->
			<xsl:copy-of select="$rc007"/>
			<xsl:copy-of select="$vc019"/>
		</vz846:CrediteurOrgaan>
	</xsl:template>				

	<xsl:template match="vz845:DocumentDatRechtAantoont">
		<!-- Controles voor deze klasse uitvoeren -->
		<vz846:DocumentDatRechtAantoont>
			<xsl:apply-templates select="vz845:EHICDocument"/>
			<xsl:apply-templates select="vz845:SpecifiekDocument"/>
			<xsl:apply-templates select="vz845:OverigDocument"/>
			<xsl:apply-templates select="vz845:GeldigheidRechtPeriode"/>
			<!-- feedback klasse DocumentDatRechtAantoont toevoegen -->
		</vz846:DocumentDatRechtAantoont>
	</xsl:template>				

	<xsl:template match="vz845:EHICDocument">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC009: Documentcode moet voorkomen in Code document van verdragsrecht codelijst. -->
		<xsl:variable name="rc009">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0029-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9736'"/>
				<xsl:with-param name="Code" select="vz845:Documentcode"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC022: Indien EHICDocument voorkomt, dan Documentcode = S8001 (= EHIC- Europese ziekteverzekeringskaart). -->				
		<xsl:variable name="vc022">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Documentcode"/>
				<xsl:with-param name="VereisteWaarde" select="'S8001'"/>
				<xsl:with-param name="Retourcode" select="'9724'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:EHICDocument>
			<!-- feedback klasse EHICDocument toevoegen -->
			<xsl:copy-of select="$rc009"/>
			<xsl:copy-of select="$vc022"/>
		</vz846:EHICDocument>
	</xsl:template>				

	<xsl:template match="vz845:SpecifiekDocument">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC009: Documentcode moet voorkomen in Code document van verdragsrecht codelijst. -->
		<xsl:variable name="rc009">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0029-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9736'"/>
				<xsl:with-param name="Code" select="vz845:Documentcode"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC023: Indien SpecifiekDocument voorkomt, dan Documentcode = S8002 (= Voorlopig ziekteverzekeringsbewijs( PRC)), S8004 (= S2 Recht op geplande geneeskundige behandeling), S8008 (= S045 Document dat recht aantoont - tijdelijk verblijf) of S8012 (= 112 Verklaring betreffende het behoud van het recht op uitkeringen wegens ziekte of moederschap). -->		
		<xsl:variable name="vc023">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Documentcode"/>
				<xsl:with-param name="VereisteWaarde" select="'S8002|S8004|S8008|S8012'"/>
				<xsl:with-param name="Retourcode" select="'9724'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC024: Indien Afgiftedatum voorkomt dan moet de waarde van Afgiftedatum kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->				
		<xsl:variable name="vc024">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Afgiftedatum"/>
				<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9190'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:SpecifiekDocument>
			<!-- feedback klasse SpecifiekDocument toevoegen -->
			<xsl:copy-of select="$rc009"/>
			<xsl:copy-of select="$vc023"/>
			<xsl:copy-of select="$vc024"/>
		</vz846:SpecifiekDocument>
	</xsl:template>				

	<xsl:template match="vz845:OverigDocument">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC009: Documentcode moet voorkomen in Code document van verdragsrecht codelijst. -->
		<xsl:variable name="rc009">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0029-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9736'"/>
				<xsl:with-param name="Code" select="vz845:Documentcode"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- RC010: TypePeriode moet voorkomen in Type periode waarop recht geldt codelijst. -->
		<xsl:variable name="rc010">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0031-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9737'"/>
				<xsl:with-param name="Code" select="vz845:TypePeriode"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC025: Indien OverigDocument voorkomt, dan moet Documentcode = S8003 (= S1 Inschrijving voor dekking van ziektekosten), S8005 (= S3 Geneeskundige behandeling voor ex-werknemer in voormalig land van arbeid), S8006 (= S037 Verlenging van document dat recht aantoont - geplande behandeling), S8007 (= S072 Document dat recht aantoont – woonplaats), S8009 (= S008 Document dat recht aantoont - voormalige grensarbeider - gezinslid voormalige grensarbeider), S8010 (= 106 Document dat recht aantoont – woonplaats), S8015 (=111 Verklaring voor tijdelijk verblijf), D8001 (= DA1 Recht op dekking op grond van verzekering tegen arbeidsongeval/beroepsziekte), D8002 (= DA002 Verklaring van het recht op verstrekkingen), D8003 (= DA007 Toestemming om de geplande medische behandeling te ondergaan), D8004 (= DA063 Toestemming voor vervoer) of D8005 (= 123 Verklaring betreffende het recht op verstrekkingen op grond van verzekering tegen arbeidsongevallen/beroepsziekten). -->				
		<xsl:variable name="vc025">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Documentcode"/>
				<xsl:with-param name="VereisteWaarde" select="'S8003|S8005|S8006|S8007|S8009|S8010|S8015|D8001|D8002|D8003|D8004|D8005'"/>
				<xsl:with-param name="Retourcode" select="'9724'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC026: Indien Afgiftedatum voorkomt dan moet de waarde van Afgiftedatum kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->				
		<xsl:variable name="vc026">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Afgiftedatum"/>
				<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9190'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:OverigDocument>
			<!-- feedback klasse OverigDocument toevoegen -->
			<xsl:copy-of select="$rc009"/>
			<xsl:copy-of select="$rc010"/>
			<xsl:copy-of select="$vc025"/>
			<xsl:copy-of select="$vc026"/>
		</vz846:OverigDocument>
	</xsl:template>				

	<xsl:template match="vz845:GeldigheidRechtPeriode">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- VC033: DocumentPeriode/Begindatum en DocumentPeriode/Einddatum mogen niet beiden ontbreken. -->				
		<xsl:variable name="vc033">
			<xsl:if test="not(vz845:Begindatum)">
				<xsl:call-template name="rcCheckVoorkomen">
					<xsl:with-param name="TeControlerenElement" select="vz845:Einddatum"/>
					<xsl:with-param name="Controle" select="'J'"/>
					<xsl:with-param name="Retourcode" select="'9729'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<!-- VC034: Indien OverigDocument/TypePeriode = 02 (= vaste periode) OF EHICDocument voorkomt, dan moet Einddatum voorkomen. -->				
		<xsl:variable name="vc034">
			<xsl:if test="(../vz845:OverigDocument/vz845:TypePeriode='02') or ../vz845:EHICDocument">
				<xsl:call-template name="rcCheckVoorkomen">
					<xsl:with-param name="TeControlerenElement" select="vz845:Einddatum"/>
					<xsl:with-param name="Controle" select="'J'"/>
					<xsl:with-param name="Retourcode" select="'9126'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<!-- VC035: Indien OverigDocument/TypePeriode = 01 (= open periode), dan mag Einddatum niet voorkomen. -->				
		<xsl:variable name="vc035">
			<xsl:call-template name="rcCheckVoorkomen_ConditioneleWaarde">
				<xsl:with-param name="TeControlerenElement" select="vz845:Einddatum"/>
				<xsl:with-param name="Controle" select="'N'"/>
				<xsl:with-param name="ConditioneelElement" select="../vz845:OverigDocument/vz845:TypePeriode"/>
				<xsl:with-param name="ConditioneleWaarde" select="'01'"/>
				<xsl:with-param name="Vergelijking" select="'gelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9730'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:GeldigheidRechtPeriode>
			<!-- feedback klasse GeldigheidRechtPeriode toevoegen -->
			<xsl:copy-of select="$vc033"/>
			<xsl:copy-of select="$vc034"/>
			<xsl:copy-of select="$vc035"/>
		</vz846:GeldigheidRechtPeriode>
	</xsl:template>				

	<xsl:template match="vz845:Uitkeringen">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC011: SoortPrestatie moet voorkomen in Code soort prestatie bij ziekte codelijst. -->
		<xsl:variable name="rc011">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0030-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9738'"/>
				<xsl:with-param name="Code" select="vz845:SoortPrestatie"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC027: Indien SoortPrestatie voorkomt, dan SoortPrestatie = S8001 (= Ziekte), S8002 (= Moederschap, vaderschap), S8003 (= Niet-arbeidsongeval), S8004 (= Langdurige zorg), D8001 (= Een arbeidsongeval) of D8002 (= Een beroepsziekte). -->	
		<xsl:variable name="vc027">
			<xsl:call-template name="rcCheckWaarde_ConditioneelElement">
				<xsl:with-param name="TeControlerenElement" select="vz845:SoortPrestatie"/>
				<xsl:with-param name="VereisteWaarde" select="'S8001|S8002|S8003|S8004|D8001|D8002'"/>
				<xsl:with-param name="ConditioneelElement" select="vz845:SoortPrestatie"/>
				<xsl:with-param name="Retourcode" select="'9725'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC028: Indien DocumentPeriode/Begindatum voorkomt, dan moet Uitkeringen/Periode/Begindatum gelijk zijn aan of groter zijn dan DocumentPeriode/Begindatum. -->				
		<xsl:variable name="vc028">
			<xsl:if test="../vz845:DocumentDatRechtAantoont/vz845:GeldigheidRechtPeriode/vz845:Begindatum">
				<xsl:call-template name="rcDatum_vs_Peildatum">
					<xsl:with-param name="TeControlerenDatum" select="vz845:Periode/vz845:Begindatum"/>
					<xsl:with-param name="Peildatum" select="../vz845:DocumentDatRechtAantoont/vz845:GeldigheidRechtPeriode/vz845:Begindatum"/>
					<xsl:with-param name="Vergelijking" select="'groterofgelijkaan'"/>
					<xsl:with-param name="Retourcode" select="'9726'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<!-- VC029: Indien DocumentPeriode/Einddatum voorkomt, dan moet Uitkeringen/Periode/Begindatum kleiner zijn dan of gelijk zijn aan DocumentPeriode/Einddatum. -->				
		<xsl:variable name="vc029">
			<xsl:if test="../vz845:DocumentDatRechtAantoont/vz845:GeldigheidRechtPeriode/vz845:Einddatum">
				<xsl:call-template name="rcDatum_vs_Peildatum">
					<xsl:with-param name="TeControlerenDatum" select="vz845:Periode/vz845:Begindatum"/>
					<xsl:with-param name="Peildatum" select="../vz845:DocumentDatRechtAantoont/vz845:GeldigheidRechtPeriode/vz845:Einddatum"/>
					<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
					<xsl:with-param name="Retourcode" select="'9727'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<vz846:Uitkeringen>
			<xsl:apply-templates select="vz845:Periode"/>
			<xsl:apply-templates select="vz845:Kosten"/>
			<!-- feedback klasse Uitkeringen toevoegen -->
			<xsl:copy-of select="$rc011"/>
			<xsl:copy-of select="$vc027"/>
			<xsl:copy-of select="$vc028"/>
			<xsl:copy-of select="$vc029"/>
		</vz846:Uitkeringen>
	</xsl:template>				

	<xsl:template match="vz845:Kosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<vz846:Kosten>
			<xsl:apply-templates select="vz845:MedischeZorgkosten"/>
			<xsl:apply-templates select="vz845:Medicijnkosten"/>
			<xsl:apply-templates select="vz845:Tandartskosten"/>
			<xsl:apply-templates select="vz845:LangdurigeZorgkosten"/>
			<xsl:apply-templates select="vz845:Ziekenhuisopnamekosten"/>
			<xsl:apply-templates select="vz845:OverigeKosten"/>
			<!-- feedback klasse Kosten toevoegen -->
		</vz846:Kosten>
	</xsl:template>				

	<xsl:template match="vz845:MedischeZorgkosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:MedischeZorgkosten>
			<!-- feedback klasse MedischeZorgkosten toevoegen -->
			<xsl:copy-of select="$rc012"/>
		</vz846:MedischeZorgkosten>
	</xsl:template>				

	<xsl:template match="vz845:Medicijnkosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:Medicijnkosten>
			<!-- feedback klasse Medicijnkosten toevoegen -->
			<xsl:copy-of select="$rc012"/>
		</vz846:Medicijnkosten>
	</xsl:template>				

	<xsl:template match="vz845:Tandartskosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:Tandartskosten>
			<!-- feedback klasse Tandartskosten toevoegen -->
			<xsl:copy-of select="$rc012"/>
		</vz846:Tandartskosten>
	</xsl:template>				

	<xsl:template match="vz845:LangdurigeZorgkosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- RC012: Valuta moet voorkomen in Code Valuta EU, EFTA en bilaterale Verdragslanden codelijst -->
		<xsl:variable name="rc012">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/CL0028-CAK.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9739'"/>
				<xsl:with-param name="Code" select="vz845:Valuta"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:LangdurigeZorgkosten>
			<!-- feedback klasse LangdurigeZorgkosten toevoegen -->
			<xsl:copy-of select="$rc012"/>
		</vz846:LangdurigeZorgkosten>
	</xsl:template>				

	<xsl:template match="vz845:Ziekenhuisopnamekosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- VC030: De waarde van UitkeringZiekenhuisopname/ Periode/ Begindatum is gelijk aan of groter dan de waarde van Uitkeringen/ Periode/ Begindatum. -->				
		<xsl:variable name="vc030">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Periode/vz845:Begindatum"/>
				<xsl:with-param name="Peildatum" select="../../vz845:Periode/vz845:Begindatum"/>
				<xsl:with-param name="Vergelijking" select="'groterofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9216'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC031: Indien UitkeringZiekenhuisopname/ Periode/Einddatum is gevuld dan moet de waarde van UitkeringZiekenhuisopname/ Periode/Einddatum is kleiner dan of gelijk aan de waarde van Uitkeringen/ Periode/ Einddatum.   -->				
		<xsl:variable name="vc031">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Periode/vz845:Einddatum"/>
				<xsl:with-param name="Peildatum" select="../../vz845:Periode/vz845:Einddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9216'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:Ziekenhuisopnamekosten>
			<xsl:apply-templates select="vz845:Periode"/>
			<xsl:apply-templates select="vz845:Bedrag"/>
			<!-- feedback klasse ZiekenhuisopnameKosten toevoegen -->
				<xsl:copy-of select="$vc030"/>
				<xsl:copy-of select="$vc031"/>
		</vz846:Ziekenhuisopnamekosten>
	</xsl:template>				

	<xsl:template match="vz845:OverigeKosten">
		<!-- Controles voor deze klasse uitvoeren -->
		<vz846:OverigeKosten>
			<xsl:apply-templates select="vz845:Beschrijving" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz845:Bedrag"/>
			<!-- feedback klasse OverigeKosten toevoegen -->
		</vz846:OverigeKosten>
	</xsl:template>				

	<xsl:template match="vz845:Periode">
		<!-- Controles voor deze klasse uitvoeren -->
		<!-- VC036: Indien Periode/Einddatum voorkomt, dan moet de waarde van Periode/Einddatum kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->				
		<xsl:variable name="vc036">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Einddatum"/>
				<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9731'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC037: Indien Periode/Einddatum voorkomt, dan moet de waarde van Periode/Einddatum groter zijn dan of gelijk zijn aan de waarde van Periode/Begindatum. -->				
		<xsl:variable name="vc037">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="vz845:Einddatum"/>
				<xsl:with-param name="Peildatum" select="vz845:Begindatum"/>
				<xsl:with-param name="Vergelijking" select="'groterofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9732'"/>
			</xsl:call-template>
		</xsl:variable>
		<vz846:Periode>
			<!-- feedback klasse Periode toevoegen -->
				<xsl:copy-of select="$vc036"/>
				<xsl:copy-of select="$vc037"/>
		</vz846:Periode>
	</xsl:template>				

	<!-- Copy template: als een enkel element voorkomt, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/vz/vz845/v1_0']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat($TargetNameSpace,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>