<?xml version="1.0" encoding="UTF-8"?>
<!-- vz845_586v1.0_Vecozo_stap2_v1, 10 april 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:gen="http://ei.vektis.nl/generiekefuncties"
xmlns:vz846="http://ei.vektis.nl/vz/vz846/v1_0">

	<!-- VALXSLT 2 TRAPS RETOURBERICHT  - versie Vecozo -->
	<!-- Deze xslt doet stap 2, i.e. filteren overbodige ballast met eindresultaat retourbericht -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
		
	<xsl:variable name="TargetNameSpace" select="'vz846:'"/>

	<xsl:template match="//vz846:Bericht">
		<vz846:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/vz/vz846/v1_0 vz846v1.0_587.xsd</xsl:attribute>
			<xsl:apply-templates select="vz846:Header"/>
			<xsl:apply-templates select="vz846:DeclaratieContext"/>
			<xsl:apply-templates select="vz846:Overzicht"/>
			<xsl:apply-templates select="vz846:Declaratieregel"/>
		</vz846:Bericht>
	</xsl:template>
	
	<xsl:template match="vz846:Header">
		<!-- retourneer alle gegevens van de klasse, onvoorwaardelijk voor deze klasse -->
		<vz846:Header>
			<xsl:apply-templates select="vz846:Berichtcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Berichtversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Berichtsubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Berichtsoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Verzender" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:VerzenderRol" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Ontvanger" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:OntvangerRol" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Referentienummer" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</vz846:Header>
	</xsl:template>
	
	<xsl:template match="vz846:DeclaratieContext">
		<!-- retourneer alle gegevens van de klasse, onvoorwaardelijk voor deze klasse -->
		<vz846:DeclaratieContext>
			<xsl:apply-templates select="vz846:ZorgverzekeraarscodeDeclaratie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:BegindatumVerwerkingsperiode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:EinddatumVerwerkingsperiode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Factuurnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Factuurdatum" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</vz846:DeclaratieContext>
	</xsl:template>
	
	<xsl:template match="vz846:Overzicht">
		<!-- retourneer alle gegevens van de klasse, onvoorwaardelijk voor deze klasse -->
		<vz846:Overzicht>
			<xsl:apply-templates select="vz846:TotaalAantalDeclaratieregels" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:TotaalBedragDeclaratieregels"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</vz846:Overzicht>
	</xsl:template>
	
	<xsl:template match="vz846:TotaalBedragDeclaratieregels">
		<!-- retourneer alle gegevens van de klasse, onvoorwaardelijk voor deze klasse -->
		<vz846:TotaalBedragDeclaratieregels>
			<xsl:apply-templates select="vz846:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:Valuta" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz846:DebetCreditCode" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</vz846:TotaalBedragDeclaratieregels>
	</xsl:template>

	<xsl:template match="vz846:Declaratieregel">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenDebetregels" select="count(vz846:DebetDeclaratieregel/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Persoonsgegevens/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Persoonsgegevens/vz846:PINVerzekeringsland/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Persoonsgegevens/vz846:PINWoonlandOfVerblijfsland/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Persoonsgegevens/vz846:PINVastgesteld/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Bedrag/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:BedragVreemdeValuta/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:CrediteurOrgaan/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:DocumentDatRechtAantoont/vz846:EHICDocument/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:DocumentDatRechtAantoont/vz846:SpecifiekDocument/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:DocumentDatRechtAantoont/vz846:OverigDocument/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:DocumentDatRechtAantoont/vz846:GeldigheidRechtPeriode/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Periode/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:MedischeZorgkosten/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:Medicijnkosten/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:Tandartskosten/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:LangdurigeZorgkosten/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:Ziekenhuisopnamekosten/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:Ziekenhuisopnamekosten/vz846:Periode/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:Ziekenhuisopnamekosten/vz846:Bedrag/gen:Feedback) +
			count(vz846:DebetDeclaratieregel/vz846:Uitkeringen/vz846:Kosten/vz846:OverigeKosten/vz846:Bedrag/gen:Feedback)"/>
		<xsl:variable name="FoutenCreditregels" select="count(vz846:CreditDeclaratieregel/gen:Feedback) +
			count(vz846:CreditDeclaratieregel/vz846:Persoonsgegevens/gen:Feedback)  +
			count(vz846:CreditDeclaratieregel/vz846:Persoonsgegevens/vz846:PINVerzekeringsland/gen:Feedback) +
			count(vz846:CreditDeclaratieregel/vz846:Persoonsgegevens/vz846:PINWoonlandOfVerblijfsland/gen:Feedback) +
			count(vz846:CreditDeclaratieregel/vz846:Persoonsgegevens/vz846:PINVastgesteld/gen:Feedback) +
			count(vz846:CreditDeclaratieregel/vz846:Bedrag/gen:Feedback) +
			count(vz846:CreditDeclaratieregel/vz846:BedragVreemdeValuta/gen:Feedback) +
			count(vz846:CreditDeclaratieregel/vz846:BedragKoersVerschil/gen:Feedback)"/>
		<xsl:if test="($FoutenDebetregels + $FoutenCreditregels) &gt; 0">
			<vz846:Declaratieregel>
				<xsl:apply-templates select="vz846:DebetDeclaratieregel"/>
				<xsl:apply-templates select="vz846:CreditDeclaratieregel"/>
			</vz846:Declaratieregel>
		</xsl:if>
	</xsl:template>				

	<xsl:template match="vz846:DebetDeclaratieregel">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenDebetregels" select="count(gen:Feedback) +
			count(vz846:Persoonsgegevens/gen:Feedback) +
			count(vz846:Persoonsgegevens/vz846:PINVerzekeringsland/gen:Feedback) +
			count(vz846:Persoonsgegevens/vz846:PINWoonlandOfVerblijfsland/gen:Feedback) +
			count(vz846:Persoonsgegevens/vz846:PINVastgesteld/gen:Feedback) +
			count(vz846:Bedrag/gen:Feedback) +
			count(vz846:BedragVreemdeValuta/gen:Feedback) +
			count(vz846:CrediteurOrgaan/gen:Feedback) +
			count(vz846:DocumentDatRechtAantoont/vz846:EHICDocument/gen:Feedback) +
			count(vz846:DocumentDatRechtAantoont/vz846:SpecifiekDocument/gen:Feedback) +
			count(vz846:DocumentDatRechtAantoont/vz846:OverigDocument/gen:Feedback) +
			count(vz846:DocumentDatRechtAantoont/vz846:GeldigheidRechtPeriode/gen:Feedback) +
			count(vz846:Uitkeringen/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Periode/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:MedischeZorgkosten/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:Medicijnkosten/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:Tandartskosten/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:LangdurigeZorgkosten/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:Ziekenhuisopnamekosten/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:Ziekenhuisopnamekosten/vz846:Periode/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:Ziekenhuisopnamekosten/vz846:Bedrag/gen:Feedback) +
			count(vz846:Uitkeringen/vz846:Kosten/vz846:OverigeKosten/vz846:Bedrag/gen:Feedback)"/>
		<xsl:if test="$FoutenDebetregels &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:DebetDeclaratieregel>
				<xsl:apply-templates select="vz846:Referentienummer" mode="copy-if-exists"/>
				<xsl:apply-templates select="vz846:Persoonsgegevens"/>
				<xsl:apply-templates select="vz846:Bedrag"/>
				<xsl:apply-templates select="vz846:BedragVreemdeValuta"/>
				<xsl:apply-templates select="vz846:CrediteurOrgaan"/>
				<xsl:apply-templates select="vz846:DocumentDatRechtAantoont"/>
				<xsl:apply-templates select="vz846:Uitkeringen"/>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:DebetDeclaratieregel>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="vz846:CreditDeclaratieregel">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenCreditregels" select="count(gen:Feedback) + 
			count(vz846:Persoonsgegevens/gen:Feedback) +
			count(vz846:Persoonsgegevens/vz846:PINVerzekeringsland/gen:Feedback) +
			count(vz846:Persoonsgegevens/vz846:PINWoonlandOfVerblijfsland/gen:Feedback) +
			count(vz846:Persoonsgegevens/vz846:PINVastgesteld/gen:Feedback) +
			count(vz846:Bedrag/gen:Feedback) +
			count(vz846:BedragVreemdeValuta/gen:Feedback) +
			count(vz846:BedragKoersVerschil/gen:Feedback)"/>
		<xsl:if test="$FoutenCreditregels &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:CreditDeclaratieregel>
				<xsl:apply-templates select="vz846:Referentienummer" mode="copy-if-exists"/>
				<xsl:apply-templates select="vz846:Persoonsgegevens"/>
				<xsl:apply-templates select="vz846:Bedrag"/>
				<xsl:apply-templates select="vz846:BedragVreemdeValuta"/>
				<xsl:apply-templates select="vz846:BedragKoersVerschil"/>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:CreditDeclaratieregel>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="vz846:Persoonsgegevens">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenPers" select="count(gen:Feedback) + 
			count(vz846:PINVerzekeringsland/gen:Feedback) + 
			count(vz846:PINWoonlandOfVerblijfsland/gen:Feedback) + 
			count(vz846:PINVastgesteld/gen:Feedback)"/>
		<xsl:if test="$FoutenPers &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Persoonsgegevens>
				<xsl:apply-templates select="vz846:PINVerzekeringsland"/>
				<xsl:apply-templates select="vz846:PINWoonlandOfVerblijfsland"/>
				<xsl:apply-templates select="vz846:PINVastgesteld"/>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Persoonsgegevens>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:PINVerzekeringsland">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenPIN" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenPIN &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:PINVerzekeringsland>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:PINVerzekeringsland>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:PINWoonlandOfVerblijfsland">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenPIN" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenPIN &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:PINWoonlandOfVerblijfsland>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:PINWoonlandOfVerblijfsland>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:PINVastgesteld">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenPIN" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenPIN &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:PINVastgesteld>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:PINVastgesteld>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:CrediteurOrgaan">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenCrediteurOrgaan" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenCrediteurOrgaan &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:CrediteurOrgaan>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:CrediteurOrgaan>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:DocumentDatRechtAantoont">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenDoc" select="count(vz846:EHICDocument/gen:Feedback) + 
					count(vz846:SpecifiekDocument/gen:Feedback) + count(vz846:OverigDocument/gen:Feedback) +
					count(vz846:GeldigheidRechtPeriode/gen:Feedback)"/>
		<xsl:if test="$FoutenDoc &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:DocumentDatRechtAantoont>
				<xsl:apply-templates select="vz846:EHICDocument"/>
				<xsl:apply-templates select="vz846:SpecifiekDocument"/>
				<xsl:apply-templates select="vz846:OverigDocument"/>
				<xsl:apply-templates select="vz846:GeldigheidRechtPeriode"/>
			</vz846:DocumentDatRechtAantoont>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:EHICDocument">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenEHICDoc" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenEHICDoc &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:EHICDocument>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:EHICDocument>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:SpecifiekDocument">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenSpecifiekDoc" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenSpecifiekDoc &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:SpecifiekDocument>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:SpecifiekDocument>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:OverigDocument">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenOverigDoc" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenOverigDoc &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:OverigDocument>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:OverigDocument>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:GeldigheidRechtPeriode">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenGeldigheidRechtPeriode" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenGeldigheidRechtPeriode &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:GeldigheidRechtPeriode>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:GeldigheidRechtPeriode>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Uitkeringen">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenUitk" select="count(gen:Feedback) +
			count(vz846:Periode/gen:Feedback) +
			count(vz846:Kosten/vz846:MedischeZorgkosten/gen:Feedback) +
			count(vz846:Kosten/vz846:Medicijnkosten/gen:Feedback) +
			count(vz846:Kosten/vz846:Tandartskosten/gen:Feedback) +
			count(vz846:Kosten/vz846:LangdurigeZorgkosten/gen:Feedback) +
			count(vz846:Kosten/vz846:Ziekenhuisopnamekosten/gen:Feedback) +
			count(vz846:Kosten/vz846:Ziekenhuisopnamekosten/vz846:Periode/gen:Feedback) +
			count(vz846:Kosten/vz846:Ziekenhuisopnamekosten/vz846:Bedrag/gen:Feedback) +
			count(vz846:Kosten/vz846:OverigeKosten/vz846:Bedrag/gen:Feedback)"/>
		<xsl:if test="$FoutenUitk &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Uitkeringen>
				<xsl:apply-templates select="vz846:Periode"/>
				<xsl:apply-templates select="vz846:Kosten"/>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Uitkeringen>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Kosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenKosten" select="
			count(vz846:MedischeZorgkosten/gen:Feedback) +
			count(vz846:Medicijnkosten/gen:Feedback) +
			count(vz846:Tandartskosten/gen:Feedback) +
			count(vz846:LangdurigeZorgkosten/gen:Feedback) +
			count(vz846:Ziekenhuisopnamekosten/gen:Feedback) +
			count(vz846:Ziekenhuisopnamekosten/vz846:Periode/gen:Feedback) +
			count(vz846:Ziekenhuisopnamekosten/vz846:Bedrag/gen:Feedback) +
			count(vz846:OverigeKosten/vz846:Bedrag/gen:Feedback)"/>
		<xsl:if test="$FoutenKosten &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Kosten>
				<xsl:apply-templates select="vz846:MedischeZorgkosten"/>
				<xsl:apply-templates select="vz846:Medicijnkosten"/>
				<xsl:apply-templates select="vz846:Tandartskosten"/>
				<xsl:apply-templates select="vz846:LangdurigeZorgkosten"/>
				<xsl:apply-templates select="vz846:Ziekenhuisopnamekosten"/>
				<xsl:apply-templates select="vz846:OverigeKosten"/>
			</vz846:Kosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:MedischeZorgkosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="Fouten" select="count(gen:Feedback)"/>
		<xsl:if test="$Fouten &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:MedischeZorgkosten>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:MedischeZorgkosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Medicijnkosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="Fouten" select="count(gen:Feedback)"/>
		<xsl:if test="$Fouten &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Medicijnkosten>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Medicijnkosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Tandartskosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="Fouten" select="count(gen:Feedback)"/>
		<xsl:if test="$Fouten &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Tandartskosten>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Tandartskosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:LangdurigeZorgkosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="Fouten" select="count(gen:Feedback)"/>
		<xsl:if test="$Fouten &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:LangdurigeZorgkosten>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:LangdurigeZorgkosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Ziekenhuisopnamekosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenZkhOpname" select="count(gen:Feedback) + count(vz846:Periode/gen:Feedback) + count(vz846:Bedrag/gen:Feedback)"/>
		<xsl:if test="$FoutenZkhOpname &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Ziekenhuisopnamekosten>
				<xsl:apply-templates select="vz846:Periode"/>
				<xsl:apply-templates select="vz846:Bedrag"/>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Ziekenhuisopnamekosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:OverigeKosten">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="Fouten" select="count(vz846:Bedrag/gen:Feedback)"/>
		<xsl:if test="$Fouten &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:OverigeKosten>
				<xsl:apply-templates select="vz846:Beschrijving" mode="copy-if-exists"/>
				<xsl:apply-templates select="vz846:Bedrag"/>
			</vz846:OverigeKosten>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Periode">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenPeriode" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenPeriode &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Periode>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Periode>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:Bedrag">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenBedrag" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenBedrag &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:Bedrag>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:Bedrag>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:BedragVreemdeValuta">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenBedrag" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenBedrag &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:BedragVreemdeValuta>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:BedragVreemdeValuta>
		</xsl:if>
	</xsl:template>

	<xsl:template match="vz846:BedragKoersVerschil">
		<!-- retourneer de klasse inclusief identificerende gegevens als klasse en/of subklassen één of meer fouten bevat -->
		<xsl:variable name="FoutenBedrag" select="count(gen:Feedback)"/>
		<xsl:if test="$FoutenBedrag &gt; 0">
			<!-- fout gevonden, retourneer klasse -->
			<vz846:BedragKoersVerschil>
				<!-- retourneer feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</vz846:BedragKoersVerschil>
		</xsl:if>
	</xsl:template>

	<xsl:template match="gen:Feedback">
	<vz846:Feedback>
		<xsl:apply-templates select="gen:Retourcode" mode="copy-if-exists"/>
		<xsl:apply-templates select="gen:BetrokkenElement"/>
	</vz846:Feedback>
	</xsl:template>
	<xsl:template match="gen:BetrokkenElement">
		<vz846:BetrokkenElement>
			<xsl:apply-templates select="*" mode="copy-if-exists"/>
		</vz846:BetrokkenElement>
	</xsl:template>
	
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/vz/vz846/v1_0']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat($TargetNameSpace,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/generiekefuncties']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat($TargetNameSpace,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
